@@ -831,12 +831,14 @@ class SASsessionHTTP():
       headers={"Accept":"application/vnd.sas.collection+json", "Authorization":"Bearer "+self.sascfg._token}
       while i < len(results):
          # GET an ODS Result
-         if results[i].get('type') == 'ODS' and len(results[i].get('links')) > 0:
-            conn.request('GET', results[i].get('links')[0].get('href'), headers=headers)
-            req = conn.getresponse()
-            status = req.status
-            resp = req.read()
-            htm += resp.decode(self.sascfg.encoding)
+         if results[i].get('type') == 'ODS'         and \
+            results[i].get('name').endswith('.htm') and \
+            len(results[i].get('links')) > 0:
+               conn.request('GET', results[i].get('links')[0].get('href'), headers=headers)
+               req = conn.getresponse()
+               status = req.status
+               resp = req.read()
+               htm += resp.decode(self.sascfg.encoding)
          i += 1
       conn.close()
 
